@@ -3,7 +3,7 @@
 #
 # Author: Slaven Rezic
 #
-# Copyright (C) 2009,2010 Slaven Rezic. All rights reserved.
+# Copyright (C) 2009,2010,2012 Slaven Rezic. All rights reserved.
 # This package is free software; you can redistribute it and/or
 # modify it under the same terms as Perl itself.
 #
@@ -17,7 +17,7 @@ use 5.006; # sprintf("%b")
 
 use strict;
 use vars qw($VERSION);
-$VERSION = '0.02';
+$VERSION = '0.03';
 
 sub encode_number {
 #   1. Take the initial signed value:
@@ -72,14 +72,13 @@ sub encode_number {
 sub encode_polyline {
     my(@path) = @_;
     my @res;
-    my($curr_lat,$curr_lon) = do { my $first = shift @path; ($first->{lat}, $first->{lon}) };
-    push @res, encode_number($curr_lat), encode_number($curr_lon);
+    my($curr_lat_e5,$curr_lon_e5) = (0,0);
     for my $lat_lon (@path) {
-        my($lat,$lon) = ($lat_lon->{lat}, $lat_lon->{lon});
-        my $deltay = $lat - $curr_lat;
-        my $deltax = $lon - $curr_lon;
+	my($lat_e5,$lon_e5) = map { sprintf("%.0f", $_*1e5) } ($lat_lon->{lat}, $lat_lon->{lon});
+        my $deltay = ($lat_e5 - $curr_lat_e5) / 1e5;
+        my $deltax = ($lon_e5 - $curr_lon_e5) / 1e5;
         push @res, encode_number($deltay), encode_number($deltax);
-        ($curr_lat,$curr_lon) = ($lat,$lon);
+        ($curr_lat_e5,$curr_lon_e5) = ($lat_e5,$lon_e5);
     }
     join '', @res;
 }
@@ -239,7 +238,7 @@ Slaven Rezic <srezic@cpan.org>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2009,2010 Slaven Rezic. All rights reserved.
+Copyright (c) 2009,2010,2012 Slaven Rezic. All rights reserved.
 This module is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
 
